//=============================================================================
// File: error.c
// Func: print error messages
// Copr: (C)2009 - 2010 by Frank Wuerriehausen, MPI bpc Goettingen
//       http://
// Link:
// Load:
//=============================================================================

#include <string.h>
#include "com.h"
#include "error.h"

//-----------------------------------------------------------------------------
	const char	*errorText[] =
	{
//			  1			2		  3			4		  5			6
//	 123456789012345678901234567890123456789012345678901234567890
	"SPI timeout",													// SPI_ERROR_TIMEOUT
	"SPI wrong argument",											// SPI_ERROR_ARGUMENT
	"SPI overrun error",											// SPI_ERROR_OVERRUN
	"SPI mode fault error",											// SPI_ERROR_MODE_FAULT
	"SPI overrun and mode fault",									// SPI_ERROR_OVERRUN_AND_MODE_FAULT
	"SPI general error",											// if error < 0
	"not a number",													// NO_NUMBER
	"number is out of range",										// ERR_RANGE
	"wrong channel",												// WRONG_CHANNEL
	"wrong command",												// ERROR_IN_COMMAND
	"argument missing",												// NO_ARGUMENT
	"too less arguments for this command",							// LESS_ARGUMENTS
	"please stop the calculation first",							// CALCULATION_RUNNING
	"wrong date",													// ERROR_IN_DATE
	"memory could not be allocated",								// NO_MEMORY
	"the option is wrong or no option",								// WRONG_OPTION
	"serial flash density error",									// SF_DENSITY
	"serial flash is protected",									// SF_PROTECT
	"serial flash has the wrong page size (1024)",					// SF_PAGE_SIZE
	"unable to mount drive",										// ERR_MOUNT
	"drive does not exist",											// ERR_DRIVE
	"can not erase; if the name is a directory, check it is empty",	// ERR_RM
	"unknown file",													// ERR_UNKNOWN_FILE
	"unable to create file",										// ERR_CREATE
	"error during move",											// ERR_MV
	"format fails",													// ERR_FORMAT
	"RTC invalid argument",											// INV_ARGUMENT
	"RTC arbitration lost",											// ARBITRATION_LOST
	"RTC no chip found",											// NO_CHIP_FOUND
	"RTC receiver overrun",											// RECEIVE_OVERRUN
	"RTC no acknowledge from receiver",								// RECEIVE_NACK
	"RTC transmitter overrun",										// SEND_OVERRUN
	"RTC no acknowledge from transmitter",							// SEND_NACK
	"no S-Record found",											// NO_SREC
	"no valid S-Record file",										// ERR_SREC
	"no S0 record found",											// ERR_S0
	"S1 record found",												// ERR_S1
	"S3 record found",												// ERR_S3
	"no S8 record found",											// ERR_S8
	"timeout occurred",												// ERR_TIMEOUT
	"undefined error"												// MAX_ERROR
	};


//-----------------------------------------------------------------------------
void PrintError( char *text, int error )
{
	Prints( " " );
	if (error == 0)
	{
		Prints( "no error\n" );
		return;
	}

	if (error < 0 || error > MAX_ERROR) error = MAX_ERROR;

	if (*text)
	{
		Prints( text );
		Prints( ": " );
	}
	else
	{
		Prints( "ERROR: " );
	}
	Prints( (char*)errorText[--error] );
	Prints( "\n" );
}

//-----------------------------------------------------------------------------
void GetError( char *msg, int error )
{
	if (error == 0)
	{
		strcpy( msg, "no error" );
		return;
	}
	if (error < 0 || error >= MAX_ERROR) error = MAX_ERROR;
	strcpy( msg, (char*)errorText[--error] );
}


